@@ -20,3 +20,6 @@ class HeartbeatClient:
             query += f"error={int(error_timeout.total_seconds())}"
 
         requests.post(f"{self.base_url}beat/{name}{query}")
+
+    def delete_beat(self, name):
+        requests.delete(f"{self.base_url}beat/{name}")
